@@ -19,11 +19,7 @@ GDriveUrl::GDriveUrl(const QUrl &url)
     : m_url(url)
 {
     const auto path = url.adjusted(QUrl::StripTrailingSlash).path();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    m_components = path.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
     m_components = path.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
 }
 
 QString GDriveUrl::account() const
